skim_get_data()

Skim a pandas or polars dataframe and return summary statistics as a dictionary, and without printing to the console.

Usage

skim_get_data(df_in)

skim is an alternative to pandas.DataFrame.describe(), quickly providing an overview of a data frame via a table of summary statistics. It produces a different set of summary functions based on the types of columns in the dataframe. You may get better results from ensuring that you set the datatypes in your dataframe you want before running skim.

Note that any unknown column types, or mixed column types, will not be processed.

Parameters

df_in: pd.DataFrame | pl.DataFrame

Dataframe to get summary statistics on.

Returns

JSON | str

JSON | str: Dictionary of summary statistics.