skim_get_figure()
Skim a pandas or polars dataframe, print the stats to the console, and save a version of the table as an SVG, HTML, or text file.
Usage
skim_get_figure(
df_in,
save_path,
format="svg",
)skim is an alternative to pandas.DataFrame.describe(), quickly providing an overview of a data frame via a table of summary statistics. It produces a different set of summary functions based on the types of columns in the dataframe. You may get better results from ensuring that you set the datatypes in your dataframe you want before running skim.
Note that any unknown column types, or mixed column types, will not be processed.
Parameters
df_in: pd.DataFrame | pl.DataFrame-
Dataframe to skim.
save_path: os.PathLike | str-
Path to save figure to (include extension).
format: str = "svg"-
svg, html, or text. Defaults to “svg”.
Raises
ValueError-
If the format is not one of svg, html, or text.